==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringOperationDescription } from "./WebFilteringExpressionsTreeOrFilteringOperationDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
            }
            if (a.j(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringOperation");
        }
        static d(a) {
            WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.b(a);
            a.aa("WebFilteringExpressionsTreeOrFilteringOperation", () => new WebFilteringExpressionsTreeOrFilteringOperationDescription());
            a.z("WebFilteringExpressionsTreeOrFilteringOperation", WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringOperationDescription } from "./WebFilteringExpressionsTreeOrFilteringOperationDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringOperation");
        }
        static d(a) {
            WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.b(a);
            a.ac("WebFilteringExpressionsTreeOrFilteringOperation", () => new WebFilteringExpressionsTreeOrFilteringOperationDescription());
            a.ab("WebFilteringExpressionsTreeOrFilteringOperation", WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata;
})();
